namespace Marro.PacManUdon
{
    public partial class GameManager
    {
        private void TimeSequenceStepStartNewLevel(int sequenceProgress)
        {
            switch (sequenceProgress)
            {
                case 0:
                    PrepareForCutscene();
                    
                    // Reset, show maze and score display
                    SetMazeVisible(true);
                    statusDisplay.SetScoreDisplayVisible(true);
                    statusDisplay.SetLabel1UPTextBlinking(true);
                    break;
                case 1:
                    // Increment level, show ready, show pellets, show lives indicators
                    IncrementLevel();
                    statusDisplay.SetExtraLivesDisplayVisible(true);
                    statusDisplay.SetLevelDisplayVisible(true);
                    statusDisplay.SetReadyTextVisible(true);
                    SetPelletsActive(true);
                    break;
                case 2:
                    // Show pacman, show ghosts
                    SetPacManActive(true);
                    SetGhostsActive(true);
                    break;
                case 3:
                    // Hide ready
                    statusDisplay.SetReadyTextVisible(false);
                    break;
                case 4:
                    break;
            }
        }

        private void TimeSequenceFinalizeStartNewLevel()
        {
            // Unfreeze
            SetFrozen(false);
            soundManager.SuppressSound(false);
            soundManager.StartGhostSound();
        }
    }
}
